==> react-native-digitcamera-1.2.39.tgz: package/src/Api/ApiUrls.js <==
const PROD = true;
const PRE_PROD = false;
const UAT = false; // do not change this flag, if above both flags are false then app will connect to UAT
const PROD_BASE = {
  INSTRUCTIONS: "https://prod-commondataservice.godigit.com/",
  SELF_SURVEY_SERVICES: "https://prod-selfsurveyservices.godigit.com/",
  COMMON_DATA_SERVICE: "https://prod-commondataservice.godigit.com/",
  DIGIT_CARE_NEW:"https://prod-digitcarenew.godigit.com/",
  PAYMENT_GETWAY:"https://uat-DigitPaymentGateway.godigit.com/",
};
const UAT_BASE = {
  INSTRUCTIONS: "https://uat-commondataservice.godigit.com/",
  SELF_SURVEY_SERVICES: "https://uat-selfsurveyservices.godigit.com/",
  COMMON_DATA_SERVICE: "https://uat-commondataservice.godigit.com/",
    DIGIT_CARE_NEW:"https://uat-digitcarenew.godigit.com/",
      PAYMENT_GETWAY:"https://uat-DigitPaymentGateway.godigit.com/",


};

const PREPROD_BASE = {
  INSTRUCTIONS: "https://preprod-commondataservice.godigit.com/",
  SELF_SURVEY_SERVICES: "https://preprod-selfsurveyservices.godigit.com/",
  COMMON_DATA_SERVICE: "https://preprod-commondataservice.godigit.com/",
    DIGIT_CARE_NEW:"https://preprod-digitcarenew.godigit.com/",
      PAYMENT_GETWAY:"https://preprod-DigitPaymentGateway.godigit.com/",

};

const BASE_URL = PROD ? PROD_BASE : PRE_PROD ? PREPROD_BASE : UAT_BASE;

const INSTRUCTIONS_URL =
  BASE_URL.INSTRUCTIONS + "CommonDataService/rest/survey/instructions/";
const SELFSURVEYSERVICE_DOCUMENT_URL =
  BASE_URL.SELF_SURVEY_SERVICES + "SelfSurveyServices/document";
const AGENT_DATA =
  BASE_URL.COMMON_DATA_SERVICE +
  "CommonDataService/rest/GetWebUsers?webUserId=35327650";
const POSE_DETECTION =
  BASE_URL.SELF_SURVEY_SERVICES + "SelfSurveyServices/detectPose";
const CHASSSIS_POSE_DETECTION =
  BASE_URL.SELF_SURVEY_SERVICES +
  "SelfSurveyServices/detect/chassis-plate/text";
const DOCUMENT_LAST =
  BASE_URL.SELF_SURVEY_SERVICES + "SelfSurveyServices/document/last";
const SELF_SURVEY_SERVICES_ACTIVITYID =
  BASE_URL.SELF_SURVEY_SERVICES + "SelfSurveyServices/";
const AUTO_PI_APPROVAL_URL=BASE_URL.DIGIT_CARE_NEW+"DigitCareNew/4w/auto-pi/realtime-approval?";
const AUTO_PI_PROGRESS_URL=BASE_URL.DIGIT_CARE_NEW+"DigitCareNew/4w/auto-pi/progress";
const AUTO_PI_DECISION_URL=BASE_URL.DIGIT_CARE_NEW+"DigitCareNew/get/activity/";
const PAYMENT_GETWAY_URL=BASE_URL.PAYMENT_GETWAY+"DigitPaymentGateway/rest/insertPaymentOnline/EB/Motor";
const DIGIT_PAYMENT_SUCCESS_URL=BASE_URL.PAYMENT_GETWAY+"DigitPaymentGateway/success";
const DIGIT_PAYMENT_CANCEL_URL=BASE_URL.PAYMENT_GETWAY+"DigitPaymentGateway/cancel";
const PROD_DIGIT_FEED_BACK_PAGE_URL="https://prod-customerdatadocument.godigit.com/CustomerDataDocument/feedback?feedbackSource=AUTO_PI&feedbackKey=";
const UAT_DIGIT_FEED_BACK_PAGE_URL="https://uat-customerdatadocument.godigit.com/CustomerDataDocument/feedback?feedbackSource=AUTO_PI&feedbackKey=";
const BULK_PDF_DOWNLOAD=BASE_URL.DIGIT_CARE_NEW+"DigitCareNew/bulkPdfDownload?";
export {
  INSTRUCTIONS_URL,
  SELFSURVEYSERVICE_DOCUMENT_URL,
  AGENT_DATA,
  POSE_DETECTION,
  CHASSSIS_POSE_DETECTION,
  DOCUMENT_LAST,
  SELF_SURVEY_SERVICES_ACTIVITYID,
  AUTO_PI_APPROVAL_URL,
  AUTO_PI_PROGRESS_URL,
  AUTO_PI_DECISION_URL,
  PAYMENT_GETWAY_URL,
  DIGIT_PAYMENT_SUCCESS_URL,
  DIGIT_PAYMENT_CANCEL_URL,
  PROD_DIGIT_FEED_BACK_PAGE_URL,
  UAT_DIGIT_FEED_BACK_PAGE_URL,
  BULK_PDF_DOWNLOAD
};

==> react-native-digitcamera-1.2.40.tgz: package/src/Api/ApiUrls.js <==
const PROD = true;
const PRE_PROD = false;
const UAT = false; // do not change this flag, if above both flags are false then app will connect to UAT
const PROD_BASE = {
  INSTRUCTIONS: "https://prod-commondataservice.godigit.com/",
  SELF_SURVEY_SERVICES: "https://prod-selfsurveyservices.godigit.com/",
  COMMON_DATA_SERVICE: "https://prod-commondataservice.godigit.com/",
  DIGIT_CARE_NEW:"https://prod-digitcarenew.godigit.com/",
  PAYMENT_GETWAY:"https://uat-DigitPaymentGateway.godigit.com/",
  CUSTOMER_DATA_DOCUMENT:"https://prod-customerdatadocument.godigit.com/"
};
const UAT_BASE = {
  INSTRUCTIONS: "https://uat-commondataservice.godigit.com/",
  SELF_SURVEY_SERVICES: "https://uat-selfsurveyservices.godigit.com/",
  COMMON_DATA_SERVICE: "https://uat-commondataservice.godigit.com/",
    DIGIT_CARE_NEW:"https://uat-digitcarenew.godigit.com/",
      PAYMENT_GETWAY:"https://uat-DigitPaymentGateway.godigit.com/",
  CUSTOMER_DATA_DOCUMENT:"https://uat-customerdatadocument.godigit.com/"


};

const PREPROD_BASE = {
  INSTRUCTIONS: "https://preprod-commondataservice.godigit.com/",
  SELF_SURVEY_SERVICES: "https://preprod-selfsurveyservices.godigit.com/",
  COMMON_DATA_SERVICE: "https://preprod-commondataservice.godigit.com/",
    DIGIT_CARE_NEW:"https://preprod-digitcarenew.godigit.com/",
      PAYMENT_GETWAY:"https://preprod-DigitPaymentGateway.godigit.com/",
  CUSTOMER_DATA_DOCUMENT:"https://preprod-customerdatadocument.godigit.com/"

};

const BASE_URL = PROD ? PROD_BASE : PRE_PROD ? PREPROD_BASE : UAT_BASE;

const INSTRUCTIONS_URL =
  BASE_URL.INSTRUCTIONS + "CommonDataService/rest/survey/instructions/";
const SELFSURVEYSERVICE_DOCUMENT_URL =
  BASE_URL.SELF_SURVEY_SERVICES + "SelfSurveyServices/document";
const AGENT_DATA =
  BASE_URL.COMMON_DATA_SERVICE +
  "CommonDataService/rest/GetWebUsers?webUserId=35327650";
const POSE_DETECTION =
  BASE_URL.SELF_SURVEY_SERVICES + "SelfSurveyServices/detectPose";
const CHASSSIS_POSE_DETECTION =
  BASE_URL.SELF_SURVEY_SERVICES +
  "SelfSurveyServices/detect/chassis-plate/text";
const DOCUMENT_LAST =
  BASE_URL.SELF_SURVEY_SERVICES + "SelfSurveyServices/document/last";
const SELF_SURVEY_SERVICES_ACTIVITYID =
  BASE_URL.SELF_SURVEY_SERVICES + "SelfSurveyServices/";
const AUTO_PI_APPROVAL_URL=BASE_URL.DIGIT_CARE_NEW+"DigitCareNew/4w/auto-pi/realtime-approval?";
const AUTO_PI_PROGRESS_URL=BASE_URL.DIGIT_CARE_NEW+"DigitCareNew/4w/auto-pi/progress";
const AUTO_PI_DECISION_URL=BASE_URL.DIGIT_CARE_NEW+"DigitCareNew/get/activity/";
const PAYMENT_GETWAY_URL=BASE_URL.PAYMENT_GETWAY+"DigitPaymentGateway/rest/insertPaymentOnline/EB/Motor";
const DIGIT_PAYMENT_SUCCESS_URL=BASE_URL.PAYMENT_GETWAY+"DigitPaymentGateway/success";
const DIGIT_PAYMENT_CANCEL_URL=BASE_URL.PAYMENT_GETWAY+"DigitPaymentGateway/cancel";
const DIGIT_FEED_BACK_PAGE_URL=BASE_URL.CUSTOMER_DATA_DOCUMENT+"CustomerDataDocument/feedback?feedbackSource=AUTO_PI&feedbackKey=";
const BULK_PDF_DOWNLOAD=BASE_URL.DIGIT_CARE_NEW+"DigitCareNew/bulkPdfDownload?";
export {
  INSTRUCTIONS_URL,
  SELFSURVEYSERVICE_DOCUMENT_URL,
  AGENT_DATA,
  POSE_DETECTION,
  CHASSSIS_POSE_DETECTION,
  DOCUMENT_LAST,
  SELF_SURVEY_SERVICES_ACTIVITYID,
  AUTO_PI_APPROVAL_URL,
  AUTO_PI_PROGRESS_URL,
  AUTO_PI_DECISION_URL,
  PAYMENT_GETWAY_URL,
  DIGIT_PAYMENT_SUCCESS_URL,
  DIGIT_PAYMENT_CANCEL_URL,
  BULK_PDF_DOWNLOAD,
  DIGIT_FEED_BACK_PAGE_URL
};
